"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.faultify = exports.faultyAsync = exports.faultyAsyncStream = exports.faultyasync = exports.faulty = exports.rejectWithFault = exports.throwFault = void 0;

var _highland = _interopRequireDefault(require("highland"));

var _bluebird = _interopRequireDefault(require("bluebird"));

const throwFault = (uow, ignore = false) => err => {
  /* istanbul ignore else */
  if (!ignore) {
    // adorn the troubled uow
    // for processing in the errors handler
    err.uow = uow;
  }

  throw err;
};

exports.throwFault = throwFault;

const rejectWithFault = (uow, ignore = false) => err => {
  /* istanbul ignore else */
  if (!ignore) {
    // adorn the troubled uow
    // for processing in the errors handler
    err.uow = uow;
  }

  return _bluebird.default.reject(err);
};

exports.rejectWithFault = rejectWithFault;

const faulty = (funct, ignore = false) => (uow, ...args) => {
  // eslint-disable-line consistent-return
  try {
    return funct(uow, ...args);
  } catch (e) {
    throwFault(uow, ignore)(e);
  }
};

exports.faulty = faulty;

const faultyasync = (funct, ignore = false) => (uow, ...args) => funct(uow, ...args).catch(rejectWithFault(uow, ignore));

exports.faultyasync = faultyasync;

const faultyAsyncStream = (funct, ignore = false) => (...args) => (0, _highland.default)(faultyasync(funct, ignore)(...args));

exports.faultyAsyncStream = faultyAsyncStream;
const faultyAsync = faultyAsyncStream; // backwards compatibility

exports.faultyAsync = faultyAsync;

const faultify = func => (...args) => new _bluebird.default((resolve, reject) => {
  try {
    resolve(func(...args));
  } catch (e) {
    reject(e);
  }
});

exports.faultify = faultify;